.. index:: run3 

.. highlight:: bash

.. _run3:

Getting started with run3
=========================

run3 is the main entrypoint for performing high-throughput calculations with the matador library. Broadly, the aim of run3 is to perform the same calculation, with the same parameters, on multiple structures concurrently.

.. toctree::
    :maxdepth: 0

    run3_geom
    run3_spectral
    run3_phonon
    run3_elastic
